@@ -7,6 +7,7 @@ from django.db import models
 from django.db.models.functions import Length
 from django.utils.html import format_html
 from django.utils.translation import gettext_lazy as _
+from django.urls import reverse
 from dns import rcode
 from dns.tsig import HMAC_MD5, HMAC_SHA1, HMAC_SHA224, HMAC_SHA256, HMAC_SHA384, HMAC_SHA512
 from netaddr import IPNetwork, ip
@@ -15,7 +16,7 @@ from typing import Optional
 from ipam.fields import IPNetworkField
 from ipam.models import IPAddress
 from .utils import normalize_fqdn
-from .validators import HostnameAddressValidator, HostnameValidator, validate_base64
+from .validators import HostnameAddressValidator, HostnameValidator, validate_base64, MinValueValidator, MaxValueValidator
 
 logger = logging.getLogger('netbox_ddns')
 
@@ -67,6 +68,14 @@ class Server(models.Model):
         max_length=255,
         validators=[HostnameAddressValidator()],
     )
+    server_port = models.PositiveIntegerField(
+        verbose_name=_('Server Port'),
+        default=53,
+        validators=[
+            MinValueValidator(53),
+            MaxValueValidator(65535),
+        ]
+    )
     tsig_key_name = models.CharField(
         verbose_name=_('TSIG Key Name'),
         max_length=255,
@@ -357,6 +366,9 @@ class ExtraDNSName(models.Model):
     def __str__(self):
         return self.name
 
+    def get_absolute_url(self):
+        return reverse('plugins:netbox_ddns:extradnsname_edit', args=[self.ip_address.pk, self.pk])
+
     def clean(self):
         # Ensure trailing dots from domain-style fields
         self.name = normalize_fqdn(self.name)
