@@ -2,7 +2,7 @@ import base64
 import binascii
 
 from django.core.exceptions import ValidationError
-from django.core.validators import RegexValidator, URLValidator
+from django.core.validators import RegexValidator, URLValidator, MinValueValidator, MaxValueValidator
 from django.utils.translation import gettext_lazy as _
 
 
@@ -12,7 +12,7 @@ class HostnameValidator(RegexValidator):
 
 
 class HostnameAddressValidator(RegexValidator):
-    regex = '^(' + HostnameValidator.regex + '|' + URLValidator.ipv6_re + '|' + URLValidator.host_re + ')$'
+    regex = '^(' + HostnameValidator.regex + '|' + URLValidator.ipv6_re + '|' + URLValidator.ipv4_re + '|' + URLValidator.host_re + ')$'
     message = _('Enter a valid hostname or IP address.')
 
 
